@@ -48,11 +48,11 @@ def get_json(url: str, order_by_donations: bool = False, order_by_amount: bool =
     header = {'User-Agent': 'Extra Life Donation Tracker'}
     response = None
     if order_by_donations and not order_by_amount:
-        url += "?orderBy=sumDonations%20DESC"
+        url += f"?orderBy=sumDonations%20DESC&{api_version_suffix}"
     elif order_by_amount:
-        url += "?orderBy=amount%20DESC"
+        url += f"?orderBy=amount%20DESC&{api_version_suffix}"
     else:
-        url += api_version_suffix
+        url += f"?{api_version_suffix}"
     try:
         el_io_log.debug(url)
         response = requests.get(url=url, headers=header)
@@ -71,6 +71,8 @@ def get_json(url: str, order_by_donations: bool = False, order_by_amount: bool =
         return {}
     except json.decoder.JSONDecodeError:  # pragma: no cover
         el_io_log.error("[bold red]Error with JSON response. [/bold red]")
+        el_io_log.error(f"[bold red]The request status code was {response.status_code} from {url=}[/bold red]")
+        el_io_log.error(f"[bold red]Message from server was {response.text} from {url=}[/bold red]")
         return {}
 
 
